// Copyright 2014 Canonical Ltd.
// Licensed under the AGPLv3, see LICENCE file for details.

package debugger_test

import (
	"io/ioutil"
	"strings"
	stdtesting "testing"
	"time"

	gc "launchpad.net/gocheck"

	"launchpad.net/juju-core/state/apiserver/debugger"
	"launchpad.net/juju-core/testing"
)

func TestAll(t *stdtesting.T) {
	testing.MgoTestPackage(t)
}

var logData = `machine-0: 2013-12-19 12:00:00 INFO juju.api.logger logtailer.go:1 begin of test data
machine-0: 2013-12-19 12:00:00 DEBUG juju.api.logger logtailer.go:2 the quick brown fox
machine-0: 2013-12-19 12:00:01 DEBUG juju.api.logger logtailer.go:3 jumps over the lazy dog
unit-mysql-0: 2013-12-19 12:00:10 INFO worker.uniter.jujuc server.go:1 alpha bravo charlie
unit-mysql-0: 2013-12-19 12:00:10 DEBUG worker.uniter.jujuc server.go:2 delta echo foxtrott
machine-0: 2013-12-19 12:01:00 INFO juju main.go:1 something happens
machine-0: 2013-12-19 12:01:01 INFO juju main.go:1 something happens
machine-0: 2013-12-19 12:01:05 DEBUG juju main.go:2 developer wants to know something
unit-mysql-0: 2013-12-19 12:05:00 ERROR worker.uniter.jujuc server.go:99 ouch
machine-0: 2013-12-19 12:05:01 ERROR juju main.go:2 "ouch" happened at "unit-mysql-0"
unit-wordpress-0: 2013-12-19 12:30:11 INFO worker.uniter.jujuc server.go:1 alpha bravo charlie
unit-wordpress-0: 2013-12-19 12:30:12 DEBUG worker.uniter.jujuc server.go:2 delta echo foxtrott
machine-0: 2013-12-19 12:30:30 DEBUG juju main.go:3 developer wants to know something else
unit-mysql-0: 2013-12-19 12:33:44 DEBUG juju.worker.uniter modes.go:1 HOOK foo
unit-mysql-0: 2013-12-19 12:33:44 INFO juju.worker.uniter modes.go:2 HOOK bar
machine-0: 2013-12-19 12:33:45 DEBUG juju.state.apiserver apiserver.go:102 <- [1] unit-mysql-0
unit-mysql-0: 2013-12-19 12:33:45 INFO juju.worker.uniter modes.go:3 HOOK yadda
machine-0: 2013-12-19 12:33:45 DEBUG juju.state.apiserver apiserver.go:102 <- [1] unit-wordpress-0
unit-wordpress-0: 2013-12-19 12:34:00 INFO juju.worker.uniter modes.go:1 HOOK foo
unit-wordpress-0: 2013-12-19 12:34:01 INFO juju.worker.uniter modes.go:2 HOOK bar
unit-wordpress-0: 2013-12-19 12:34:02 INFO juju.worker.uniter modes.go:3 HOOK yadda
machine-0: 2013-12-19 12:34:56 INFO juju main.go:1 something happens
unit-mysql-0: 2013-12-19 12:40:00 INFO juju.worker.uniter context.go:1 HOOK baz
unit-wordpress-0: 2013-12-19 12:41:00 INFO juju.worker.uniter context.go:1 HOOK baz
machine-0: 2013-12-19 13:00:00 INFO juju.api.logger logtailer.go:99 end of test data`

// startLogDataWriter initially writes ten log lines into a temporary file and then
// after a signal appends the rest of the data line by line.
func startLogDataWriter(c *gc.C) (string, chan struct{}, debugger.Restorer) {
	// Create temporary log file.
	logFile, err := ioutil.TempFile("", "all-machines-log")
	c.Assert(err, gc.IsNil)
	restorer := debugger.SetLogLocation(logFile.Name())
	sigc := make(chan struct{})
	// Initial lines.
	lines := strings.Split(logData, "\n")
	i := 0
	for ; i < 10; i++ {
		_, err := logFile.WriteString(lines[i] + "\n")
		c.Assert(err, gc.IsNil)
	}
	// Writing line by line in the background.
	go func() {
		<-sigc

		for ; i < len(lines); i++ {
			time.Sleep(5 * time.Millisecond)
			_, err := logFile.WriteString(lines[i] + "\n")
			c.Assert(err, gc.IsNil)
		}
		c.Assert(logFile.Close(), gc.IsNil)
	}()
	return logFile.Name(), sigc, restorer
}
